Enum symbolic_il2cpp::usym::UsymErrorKind
source · [−]pub enum UsymErrorKind {
Show 13 variants
MisalignedBuffer,
BadHeader,
BadMagic,
BadVersion,
BadRecordCount,
BufferSmallerThanAdvertised,
MissingStrings,
BadRecords,
BadId,
BadName,
BadOperatingSystem,
BadArchitecture,
BadEncoding,
}Expand description
The error type for UsymError.
Variants
MisalignedBuffer
Buffer to usym file is misaligned.
BadHeader
The header to the usym file is missing or undersized.
BadMagic
The magic string in the header is missing or malformed.
BadVersion
The version string in the usym file’s header is missing or malformed.
BadRecordCount
The record count in the header can’t be read.
BufferSmallerThanAdvertised
The size of the usym file is smaller than the amount of data it is supposed to hold according to its header.
MissingStrings
The strings section is missing.
BadRecords
A valid slice to the usym’s source records could not be created.
BadId
The assembly ID is missing or can’t be read.
BadName
The assembly name is missing or can’t be read.
BadOperatingSystem
The architecture is missing or can’t be read.
BadArchitecture
The architecture is missing or can’t be read.
BadEncoding
A part of the file is not encoded in valid UTF-8.