pub enum UsymLiteErrorKind {
Show 14 variants
MisalignedBuffer,
BadHeader,
BadMagic,
BadVersion,
BadLineCount,
BufferSmallerThanAdvertised,
MissingStringTable,
UnterminatedStringTable,
BadLines,
BadId,
BadName,
BadOperatingSystem,
BadArchitecture,
BadEncoding,
}Expand description
The error type for UsymLiteError.
Variants
MisalignedBuffer
Buffer to usym file is misaligned.
BadHeader
The header to the usym file is missing or undersized.
BadMagic
The magic string in the header is missing or malformed.
BadVersion
The version string in the usym file’s header is missing or malformed.
BadLineCount
The line count in the header can’t be read.
BufferSmallerThanAdvertised
The size of the usym file is smaller than the amount of data it is supposed to hold according to its header.
MissingStringTable
The string table is missing.
UnterminatedStringTable
The string table is not terminated by a NULL byte.
BadLines
A valid slice to the usym’s source records could not be created.
BadId
The assembly ID is missing or can’t be read.
BadName
The assembly name is missing or can’t be read.
BadOperatingSystem
The architecture is missing or can’t be read.
BadArchitecture
The architecture is missing or can’t be read.
BadEncoding
A part of the file is not encoded in valid UTF-8.