Module symbolic_il2cpp::usym
source · [−]Expand description
Parser for the Usym format.
This format can map il2cpp instruction addresses to managed file names and line numbers.
Structs
An error when dealing with UsymSymbols.
A usym file containing data on how to map native code generated by Unity’s IL2CPP back to their C# (i.e. managed) equivalents.
Enums
The error type for UsymError.
A record mapping an IL2CPP instruction address to managed code location.